<?php
/**
* @package      EasySocial
* @copyright    Copyright (C) Stack Ideas Sdn Bhd. All rights reserved.
* @license      GNU/GPL, see LICENSE.php
* EasySocial is free software. This version may have been modified pursuant
* to the GNU General Public License, and as distributed it includes or
* is derivative of works licensed under the GNU General Public License or
* other free or open source software licenses.
* See COPYRIGHT.php for copyright notices and details.
*/
defined('_JEXEC') or die('Unauthorized Access');

ES::import('admin:/includes/fields/dependencies');

class SocialFieldsUserInvitation_code extends SocialFieldItem
{
	public function __construct($options)
	{
		parent::__construct($options);
	}

	/**
	 * Displays the field input for user when they register their account.
	 *
	 * @since	2.1
	 * @access	public
	 */
	public function onRegister(&$post, &$registration)
	{
		// Get the value
		$value = !empty($post[$this->inputName]) ? $post[$this->inputName] : '';

		$error = $registration->getErrors($this->inputName);

		$this->set('value', $this->escape($value));
		$this->set('error', $error);
		$this->set('disabled', false);

		return $this->display();
	}

	/**
	 * Validates the field input for user when they register their account.
	 *
	 * @since	2.1
	 * @access	public
	 */
	public function onRegisterValidate(&$post)
	{
		$value = !empty($post[$this->inputName]) ? $post[$this->inputName] : '';

		return $this->validateInput($value);
	}

	/**
	 * Validates mini registrations
	 *
	 * @since	3.2.17
	 * @access	public
	 */
	public function onRegisterMiniValidate(&$post)
	{
		$value = !empty($post[$this->inputName]) ? $post[$this->inputName] : '';

		return $this->validateInput($value);
	}

	private function validateInput($value)
	{
		// Trim excess whitespace
		$value = trim($value);

		if ($this->isRequired() && empty($value)) {
			return $this->setError(JText::_('PLG_FIELDS_INVITATION_CODE_VALIDATION_INPUT_REQUIRED'));
		}

		// Get lists of codes
		$codes = $this->getCodes();

		if (!in_array($value, $codes)) {
			return $this->setError(JText::_('PLG_FIELDS_INVITATION_CODE_VALIDATION_INPUT_INVALID'));
		}

		return true;
	}

	/**
	 * Retrieves the stored codes in array form
	 *
	 * @since	2.1
	 * @access	private
	 */
	private function getCodes()
	{
		$codes = $this->getParams()->get('code_listing');

		$codes = explode("\n", $codes);

		return $codes;
	}

	/**
	 * Finalize the codes state after user is registered
	 *
	 * @since	2.1
	 * @access	public
	 */
	public function onRegisterAfterSave(&$post, &$user)
	{
		if (isset($post[$this->inputName]) && $post[$this->inputName]) {
			$this->removeCode($post[$this->inputName]);
		}
	}

	/**
	 * Remove used code from the field config
	 *
	 * @since	2.1
	 * @access	private
	 */
	private function removeCode($value)
	{
		// Get the params
		$params = $this->getParams();

		// Convert the params to array
		$codes = $params->get('code_listing');

		$codes = explode("\n", $codes);

		// Flip values to keys
		$codes = array_flip($codes);

		// Unset the used code
		unset($codes[$value]);

		// Re-flip keys to values
		$codes = array_flip($codes);

		// Convert back to string
		$codes = implode("\n", $codes);

		// Re-set the params
		$params->set('code_listing', $codes);

		$tbl = ES::table('Field');
		$tbl->load($this->field->id);

		$tbl->params = $params->toString();
		$tbl->store();
	}

	/**
	 * Checks if this field is filled in.
	 *
	 * @since  2.1
	 * @access public
	 */
	public function onProfileCompleteCheck($user)
	{
		return true;
	}
}
